man > git-unpack-objects(1)

⚡ TLDR: git-unpack-objects (tldr-pages)

Git command for unpacking objects from a packed archive.

  • Simulate the pack file without unpacking objects
    git < {{pack-file.pack}} unpack-objects -n
  • Suppress percentage progress typically shown by the command
    git < {{pack-file.pack}} unpack-objects -q
  • Unpack a corrupt packfile beyond the first corruption
    git < {{pack-file.pack}} unpack-objects -r
  • Don't write objects containing broken content or links
    git < {{pack-file.pack}} unpack-objects --strict
  • Die, given a pack larger than `size`
    git < {{pack-file.pack}} unpack-objects --max-input-size={{size}}
GIT-UNPACK-OBJECTS(1)                        Git Manual                        GIT-UNPACK-OBJECTS(1)

NAME
       git-unpack-objects - Unpack objects from a packed archive

SYNOPSIS
       git unpack-objects [-n] [-q] [-r] [--strict]


DESCRIPTION
       Read a packed archive (.pack) from the standard input, expanding the objects contained within
       and writing them into the repository in "loose" (one object per file) format.

       Objects that already exist in the repository will not be unpacked from the packfile.
       Therefore, nothing will be unpacked if you use this command on a packfile that exists within
       the target repository.

       See git-repack(1) for options to generate new packs and replace existing ones.

OPTIONS
       -n
           Dry run. Check the pack file without actually unpacking the objects.

       -q
           The command usually shows percentage progress. This flag suppresses it.

       -r
           When unpacking a corrupt packfile, the command dies at the first corruption. This flag
           tells it to keep going and make the best effort to recover as many objects as possible.

       --strict
           Don’t write objects with broken content or links.

       --max-input-size=<size>
           Die, if the pack is larger than <size>.

GIT
       Part of the git(1) suite

Git 2.43.0                                   07/02/2025                        GIT-UNPACK-OBJECTS(1)

Generated by phpman v4.12.11 · Markdown · JSON Author: Che Dong Under GNU General Public License
2026-10-20 22:24 @216.73.217.130
CrawledBy Mozilla/5.0 AppleWebKit/537.36 (KHTML, like Gecko; compatible; ClaudeBot/1.0; +claudebot@anthropic.com)
Valid XHTML 1.0 Transitional!Valid CSS!